==> haskell-semigroups-0.18.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-semigroups/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.1
id: semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
key: semig_IBlkGPjZsYWGswV1yLDA9m
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic Data.Semigroup Data.List.NonEmpty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroups-0.18.1
hs-libraries: HSsemigroups-0.18.1-IBlkGPjZsYWGswV1yLDA9m
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.18.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-semigroups/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.1
id: semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
key: semig_Iivsiy35cmk8ISqG11MEap
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic Data.Semigroup Data.List.NonEmpty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroups-0.18.1
hs-libraries: HSsemigroups-0.18.1-Iivsiy35cmk8ISqG11MEap
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
